/* nqs_checkbal.c - hook to check user accounting information.
 *     returning a negative value will set the job's priority
 *     to zero (ie "goodwill" job).
 */

#include <sys/types.h>

int nqs_checkbal(uid_t uid)
{
     return (0);
}
